@@ -2,6 +2,5 @@
 
 from __future__ import absolute_import
 
-from cbc_sdk.endpoint_standard.base import Device, Event, Policy, EnrichedEvent, Query, EnrichedEventQuery, \
-                                           EnrichedEventFacet 
+from cbc_sdk.endpoint_standard.base import Event, Policy, EnrichedEvent, EnrichedEventFacet 
 from cbc_sdk.endpoint_standard.usb_device_control import USBDeviceApproval, USBDeviceBlock, USBDevice
