@@ -15,8 +15,7 @@
 
 from cbc_sdk.errors import ApiError, ServerError
 from cbc_sdk.platform import PlatformModel
-from cbc_sdk.workload import DeviceVulnerability
-from cbc_sdk.workload.vulnerability_assessment import DeviceVulnerabilityQuery
+from cbc_sdk.platform.vulnerability_assessment import Vulnerability, VulnerabilityQuery
 from cbc_sdk.base import (BaseQuery, QueryBuilder, QueryBuilderSupportMixin, CriteriaBuilderSupportMixin,
                           IterableQueryMixin, AsyncQueryMixin)
 
@@ -172,21 +171,11 @@ class Device(PlatformModel):
         """
         return self._cb.device_update_sensor_version([self._model_unique_id], sensor_version)
 
-    def vulnerability_refresh(self, vcenter_specific=False):
-        """
-        Perform an action on a specific device. Only REFRESH is supported.
-
-        Args:
-            vcenter_specific (boolean): (optional) whether to peform an action on a specific vCenter device
-        """
+    def vulnerability_refresh(self):
+        """Perform an action on a specific device. Only REFRESH is supported."""
         request = {"action_type": 'REFRESH'}
         url = "/vulnerability/assessment/api/v1/orgs/{}".format(self._cb.credentials.org_key)
 
-        # check whether vcenter_uuid is populated
-        if vcenter_specific and self.vcenter_uuid:
-            url += '/vcenters/{}'.format(self.vcenter_uuid)
-        else:
-            self._vcenter_specific = None
         url += '/devices/{}/device_actions'.format(self._model_unique_id)
 
         resp = self._cb.post_object(url, body=request)
@@ -197,45 +186,42 @@ class Device(PlatformModel):
         else:
             raise ServerError(error_code=resp.status_code, message="Device action error: {0}".format(resp.content))
 
-    def get_vulnerability_summary(self, category=None, vcenter_specific=False):
+    def get_vulnerability_summary(self, category=None):
         """
         Get the vulnerabilities associated with this device
 
         Args:
             category (string): (optional) vulnerabilty category (OS, APP)
-            vcenter_specific (boolean): (optional) return vulnerability for device in specific vCenter
 
         Returns:
             dict: summary for the vulnerabilities for this device
         """
-        if vcenter_specific and self.vcenter_uuid:
-            vcenter_id = self.vcenter_uuid
-        else:
-            vcenter_id = None
-        return DeviceVulnerability.get_vulnerability_summary_per_device(self._cb,
-                                                                        self._model_unique_id,
-                                                                        category,
-                                                                        vcenter_id)
+        VALID_CATEGORY = ["OS", "APP"]
 
-    def get_vulnerabilties(self, vcenter_specific=False):
+        query_params = {}
+
+        url = '/vulnerability/assessment/api/v1/orgs/{}'
+
+        if category and category not in VALID_CATEGORY:
+            raise ApiError("Invalid category provided")
+        elif category:
+            query_params["category"] = category
+
+        req_url = url.format(self._cb.credentials.org_key) + '/devices/{}/vulnerabilities/summary'.format(self.id)
+        return self._cb.get_object(req_url, query_params)
+
+    def get_vulnerabilties(self):
         """
         Get an Operating System or Application Vulnerability List for a specific device.
 
-        Args:
-            vcenter_specific (boolean): (optional) whether to return the vulnerabilities for vCenter
-
         Returns:
             dict: vulnerabilities for this device
         """
-        if vcenter_specific and self.vcenter_uuid:
-            self._vcenter_specific = self.vcenter_uuid
-        else:
-            self._vcenter_specific = None
-        return DeviceVulnerabilityQuery(self, self._cb)
+        return VulnerabilityQuery(Vulnerability, self._cb, self)
 
 
-"""Device Queries"""
-
+############################################
+# Device Queries
 
 class DeviceSearchQuery(BaseQuery, QueryBuilderSupportMixin, CriteriaBuilderSupportMixin,
                         IterableQueryMixin, AsyncQueryMixin):
@@ -520,7 +506,7 @@ class DeviceSearchQuery(BaseQuery, QueryBuilderSupportMixin, CriteriaBuilderSupp
             mycrit["last_contact_time"] = self._time_filter
         request = {"criteria": mycrit, "exclusions": self._exclusions}
         request["query"] = self._query_builder._collapse()
-        if from_row > 0:
+        if from_row > 1:
             request["start"] = from_row
         if max_rows >= 0:
             request["rows"] = max_rows
@@ -563,12 +549,14 @@ class DeviceSearchQuery(BaseQuery, QueryBuilderSupportMixin, CriteriaBuilderSupp
 
         return self._total_results
 
-    def _perform_query(self, from_row=0, max_rows=-1):
+    def _perform_query(self, from_row=1, max_rows=-1):
         """
         Performs the query and returns the results of the query in an iterable fashion.
 
+        Device v6 API uses base 1 instead of 0.
+
         Args:
-            from_row (int): The row to start the query at (default 0).
+            from_row (int): The row to start the query at (default 1).
             max_rows (int): The maximum number of rows to be returned (default -1, meaning "all").
 
         Returns:
